pub struct DmaObject { /* private fields */ }Expand description
A handle for an object that can be used to perform DMA, and is most useful directly as a way to perform DMA operations on a specific object. For an allocator-like DMA interface, see crate::dma::DmaPool.
Implementations
Sourceimpl DmaObject
impl DmaObject
Sourcepub fn slice_region<T: DeviceSync>(
&self,
offset: usize,
len: usize,
access: Access,
options: DmaOptions,
) -> DmaSliceRegion<T>
pub fn slice_region<T: DeviceSync>( &self, offset: usize, len: usize, access: Access, options: DmaOptions, ) -> DmaSliceRegion<T>
Create a DmaSliceRegion from the base of this object, where the region represents memory
of type [T; len].