DmaPool

Struct DmaPool 

pub struct DmaPool { /* private fields */ }
A pool for allocating DMA regions that all share a common access type and DMA options.

Implementations

Source

impl DmaPool

pub fn new(spec: ObjectBuilder<()>, access: Access, opts: DmaOptions) -> Self

Create a new DmaPool with access and DMA options, where each created underlying Twizzler object is created using the provided [ObjectBuilder]. If default (volatile) options are acceptable for the create spec, use the crate::dma::DmaPool::default_spec function.

pub fn default_spec() -> ObjectBuilder<()>

pub fn allocate<'a, T: DeviceSync>( &'a self, init: T, ) -> Result<DmaRegion<T>, TwzError>

Allocate a new [DmaRegion] from the pool. The region will be initialized with the provided initial value.

pub fn allocate_array<'a, T: DeviceSync + Clone>( &'a self, count: usize, init: T, ) -> Result<DmaSliceRegion<T>, TwzError>

Allocate a new [DmaSliceRegion] from the pool. Each entry in the region’s slice will be initialized with the provided initial value.

pub fn allocate_array_with<'a, T: DeviceSync>( &'a self, count: usize, init: impl Fn() -> T, ) -> Result<DmaSliceRegion<T>, TwzError>

Allocate a new [DmaSliceRegion] from the pool. Each entry in the region’s slice will be initialized by running the provided closure.